# JAX Utilities

## Shape and Type Checking
::: fdtdx.core.jax.utils.check_shape_dtype

## Utility Classes
::: fdtdx.core.misc.PaddingConfig

## Gradient Estimators
::: fdtdx.core.jax.ste.straight_through_estimator
